/*
* SocketTunnel - Socket Proxies to create services proxies that can 
* be controlled by application test suites.
*
* Copyright (C) 2004  Abhilash Koneri
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package net.sf.jshell2;

import java.io.*;
import java.util.*;
import java.net.*;
import javax.net.ssl.*;
import java.security.*;
import java.security.cert.*;

/*******************
 * <code>JSKeyManager</code> is a simple key manager uses a server to key-alias
 * mapping to determine the client cert to be presented to the server during the
 * SSL handshake.
 * 
 * @author Abhilash Koneri
 * @since nothing 0.0
 */
public class JSKeyManager implements X509KeyManager
{
    private X509KeyManager defaultKeyManager;
    private Properties serverMap;


    public JSKeyManager(X509KeyManager defaultKeyManager, Properties serverMap)
    {
        this.defaultKeyManager = defaultKeyManager;
        this.serverMap = serverMap;
    }


    public String chooseClientAlias(String[] keyType, Principal[] issuers, Socket socket)
    {
        SocketAddress socketAddress = socket.getRemoteSocketAddress();
        String hostName = ((InetSocketAddress)socketAddress).getHostName().toUpperCase();
        String alias = null;
        if(serverMap.containsKey(hostName))
        {
            alias = serverMap.getProperty(hostName);
            if(alias != null &&
                    alias.length() ==0)
            {
                alias = null;
            }
        }
        else
        {
            alias = defaultKeyManager.chooseClientAlias(keyType, issuers, socket);
        }
        return alias;
    }

    public String chooseServerAlias(String keyType, Principal[] issuers, Socket socket)
    {
        System.out.println("chooseServerAlias()");
        return defaultKeyManager.chooseServerAlias(keyType, issuers, socket);
    }


    public X509Certificate[] getCertificateChain(String alias)
    {
        System.out.println("getCertificateChain()");
        return defaultKeyManager.getCertificateChain(alias);
    }

    public PrivateKey getPrivateKey(String alias)
    {
        System.out.println("getPrivateKey()");
        return defaultKeyManager.getPrivateKey(alias);
    }

    public String[] getClientAliases(String keyType, Principal[] issuers)
    {
        System.out.println("getClientAliases()");
        return defaultKeyManager.getClientAliases(keyType,issuers);
    }

    public String[] getServerAliases(String keyType, Principal[] issuers)
    {
        System.out.println("getServerAliases()");
        return defaultKeyManager.getServerAliases(keyType,issuers);
    }
}
